@@ -13,9 +13,8 @@
 #define ZYPP_MEDIA_MEDIACURL_H
 
 #include <zypp/base/Flags.h>
-#include <zypp/media/TransferSettings.h>
-#include <zypp/media/MediaHandler.h>
 #include <zypp/ZYppCallbacks.h>
+#include <zypp/media/MediaNetworkCommonHandler.h>
 
 #include <curl/curl.h>
 
@@ -29,7 +28,7 @@ namespace zypp {
  * @short Implementation class for FTP, HTTP and HTTPS MediaHandler
  * @see MediaHandler
  **/
-class MediaCurl : public MediaHandler
+class MediaCurl : public MediaNetworkCommonHandler
 {
   public:
     enum RequestOption
@@ -53,7 +52,7 @@ class MediaCurl : public MediaHandler
 
     virtual void attachTo (bool next = false) override;
     virtual void releaseFrom( const std::string & ejectDev ) override;
-    virtual void getFile( const Pathname & filename, const ByteCount &expectedFileSize_r ) const override;
+    virtual void getFile( const OnMediaLocation & file ) const override;
     virtual void getDir( const Pathname & dirname, bool recurse_r ) const override;
     virtual void getDirInfo( std::list<std::string> & retlist,
                              const Pathname & dirname, bool dots = true ) const override;
@@ -82,14 +81,14 @@ class MediaCurl : public MediaHandler
      * \throws MediaException
      *
      */
-    virtual void getFileCopy( const Pathname & srcFilename, const Pathname & targetFilename, const ByteCount &expectedFileSize_r) const override;
+    virtual void getFileCopy( const OnMediaLocation& srcFile, const Pathname & targetFilename ) const override;
 
     /**
      *
      * \throws MediaException
      *
      */
-    virtual void doGetFileCopy( const Pathname & srcFilename, const Pathname & targetFilename, callback::SendReport<DownloadProgressReport> & _report, const ByteCount &expectedFileSize_r,  RequestOptions options = OPTION_NONE ) const;
+    virtual void doGetFileCopy( const OnMediaLocation &srcFile, const Pathname & targetFilename, callback::SendReport<DownloadProgressReport> & _report,  RequestOptions options = OPTION_NONE ) const;
 
 
     virtual bool checkAttachPoint(const Pathname &apoint) const override;
@@ -97,26 +96,24 @@ class MediaCurl : public MediaHandler
   public:
 
     MediaCurl( const Url &      url_r,
-	       const Pathname & attach_point_hint_r );
+               const Pathname & attach_point_hint_r );
 
     virtual ~MediaCurl() override { try { release(); } catch(...) {} }
 
-    TransferSettings & settings();
-
     static void setCookieFile( const Pathname & );
 
     class Callbacks
     {
       public:
-	virtual ~Callbacks();
+        virtual ~Callbacks();
         virtual bool progress( int percent ) = 0;
     };
 
   protected:
-//     /** Callback sending just an alive trigger to the UI, without stats (e.g. during metalink download). */
-    static int aliveCallback( void *clientp, double dltotal, double dlnow, double ultotal, double ulnow );
+    /** Callback sending just an alive trigger to the UI, without stats (e.g. during metalink download). */
+    static int aliveCallback( void *clientp, curl_off_t dltotal, curl_off_t dlnow, curl_off_t ultotal, curl_off_t ulnow );
     /** Callback reporting download progress. */
-    static int progressCallback( void *clientp, double dltotal, double dlnow, double ultotal, double ulnow );
+    static int progressCallback( void *clientp, curl_off_t dltotal, curl_off_t dlnow, curl_off_t ultotal, curl_off_t ulnow );
     static CURL *progressCallback_getcurl( void *clientp );
     /**
      * check the url is supported by the curl library
@@ -129,11 +126,6 @@ class MediaCurl : public MediaHandler
      * \throws MediaCurlSetOptException if there is a problem
      **/
     virtual void setupEasy();
-    /**
-     * concatenate the attach url and the filename to a complete
-     * download url
-     **/
-    Url getFileUrl(const Pathname & filename) const;
 
     /**
      * Evaluates a curl return code and throws the right MediaException
@@ -149,7 +141,7 @@ class MediaCurl : public MediaHandler
      */
     void evaluateCurlCode(const zypp::Pathname &filename, CURLcode code, bool timeout) const;
 
-    void doGetFileCopyFile( const Pathname & srcFilename, const Pathname & dest, FILE *file, callback::SendReport<DownloadProgressReport> & _report, const ByteCount &expectedFileSize_r, RequestOptions options = OPTION_NONE ) const;
+    void doGetFileCopyFile( const OnMediaLocation & srcFile, const Pathname & dest, FILE *file, callback::SendReport<DownloadProgressReport> & report, RequestOptions options = OPTION_NONE ) const;
 
     static void resetExpectedFileSize ( void *clientp, const ByteCount &expectedFileSize );
 
@@ -165,8 +157,6 @@ class MediaCurl : public MediaHandler
     bool detectDirIndex() const;
 
   private:
-    long _curlDebug;
-
     std::string _currentCookieFile;
     static Pathname _cookieFile;
 
@@ -176,7 +166,6 @@ class MediaCurl : public MediaHandler
     CURL *_curl;
     char _curlError[ CURL_ERROR_SIZE ];
     curl_slist *_customHeaders;
-    TransferSettings _settings;
 };
 ZYPP_DECLARE_OPERATORS_FOR_FLAGS(MediaCurl::RequestOptions);
 
